unit SDKExampleMain;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms,
  Dialogs, StdCtrls, Mask, TeEngine, Series, ExtCtrls,
  TeeProcs, Chart, ComCtrls, RzSpnEdt;

type
  TMainForm = class(TForm)
    Label1: TLabel;
    Label2: TLabel;
    LabelDeviceCnt: TLabel;
    RadioWorkMode: TRadioGroup;
    Label3: TLabel;
    Label4: TLabel;
    btnSpectrum: TButton;
    ComboBoxCameraList: TComboBox;
    EditExpTime: TEdit;
    EditFrameAvgCnt: TEdit;
    btnFrameAvgCnt: TUpDown;
    RadioAutoDark: TRadioGroup;
    BtnExpTime: TUpDown;
    EditPixel: TEdit;
    EditWavelength: TEdit;
    UpDown1: TUpDown;
    Label5: TLabel;
    Label6: TLabel;
    labelWavelength: TLabel;
    UpDown2: TUpDown;
    Chart1: TChart;
    Series1: TLineSeries;
    procedure FormCreate(Sender: TObject);
    procedure FormClose(Sender: TObject; var Action: TCloseAction);
    procedure BtnSpectrumClick(Sender: TObject);
    procedure btnFrameAvgCntClick(Sender: TObject; Button: TUDBtnType);
    procedure Label1MouseDown(Sender: TObject; Button: TMouseButton;
      Shift: TShiftState; X, Y: Integer);
    procedure RadioWorkModeClick(Sender: TObject);
    procedure RadioAutoDarkClick(Sender: TObject);
    procedure BtnExpTimeChanging(Sender: TObject;
      var AllowChange: Boolean);
    procedure UpDown1Changing(Sender: TObject; var AllowChange: Boolean);
    procedure UpDown2Changing(Sender: TObject; var AllowChange: Boolean);
  private
    { Private declarations }
  public
    { Public declarations }
  end;

var
  MainForm: TMainForm;
  iDeviceCnt :integer;

implementation
uses SDKExampleDataType,PrivateDllInterface;
{$R *.dfm}

procedure TMainForm.FormCreate(Sender: TObject);
var
  ModuleNo,SerialNo:array[0..15] of Char;
  iDevice : integer;
  flag  : integer;
begin

  iDeviceCnt := MTSSE_StartDevices(MainForm.Handle);
  if iDeviceCnt = 0 then
    begin
      ShowMessage( 'There is no SSE device!');
      Application.Terminate;
    end;
    
  LabelDeviceCnt.Caption := intToStr(iDeviceCnt);
  ComboBoxCameraList.Items.Clear;

  if iDeviceCnt > 0 then
    begin
      for iDevice :=1 to iDeviceCnt do
        begin
          MTSSE_GetModuleNo(iDevice,ModuleNo);
          MTSSE_GetSerialNo(iDevice,SerialNo);
          ComboboxCameraList.Items.Add(IntToStr(iDevice) + ':'+
              String(ModuleNo) +'_'+String(SerialNo));
        end;
      ComboBoxCameraList.ItemIndex := 0;
      WorkDevice := ComboBoxCameraList.ItemIndex +1;
      MTSSE_SetWorkingDevice(WorkDevice);
      MTSSE_SetAutoDarkStatus(0);
      MTSSE_SetDeviceWorkMode(0);
    end;
 end;

procedure TMainForm.FormClose(Sender: TObject; var Action: TCloseAction);
begin
  MTSSE_StopDevices();
end;

procedure TMainForm.BtnSpectrumClick(Sender: TObject);
var
  i: integer;
begin

  MTSSE_GrabSpectrum();
  Series1.Clear;

//  Series1.AddArray(aSpectrumData);
  if ( MTSSE_GetSpectrum(pSpectrum, 1) <> nil ) then
    begin
      for i:=0 to  High(aSpectrumData) do
        begin
          Series1.AddXY(i,pSpectrum^);
          Inc( pSpectrum );
        end
    end;
end;

procedure TMainForm.btnFrameAvgCntClick(Sender: TObject;
  Button: TUDBtnType);
var
  FrameAvgCnt : integer;
begin
  FrameAvgCnt := StrToint(editFrameAvgCnt.Text);
  MTSSE_SetFrameAvgCnt(FrameAvgCnt);
end;

procedure TMainForm.Label1MouseDown(Sender: TObject; Button: TMouseButton;
  Shift: TShiftState; X, Y: Integer);
begin
 if (ssCtrl in Shift) AND (ssAlt in Shift) then
      MTSSE_FormShow();
end;

procedure TMainForm.RadioWorkModeClick(Sender: TObject);
var
  WorkMode : integer;
begin
  if RadioWorkMode.ItemIndex = 0 then
    WorkMode := 0
  else
    WorkMode := 1;
  MTSSE_SetDeviceWorkMode(WorkMode);
end;

procedure TMainForm.RadioAutoDarkClick(Sender: TObject);
var
  AutoDark:integer;
begin
  if RadioAutoDark.ItemIndex = 0 then
    AutoDark := 1
  else
    AutoDark := 0;
  MtSSE_SetAutoDarkStatus(AutoDark);
end;

procedure TMainForm.BtnExpTimeChanging(Sender: TObject;
  var AllowChange: Boolean);
var
  ExpTime : integer; // micronSec
begin
  ExpTime := StrToInt(EditExpTime.text);
  MTSSE_SetExposureTime(Exptime);
end;

procedure TMainForm.UpDown1Changing(Sender: TObject;
  var AllowChange: Boolean);
var
  tmpPixel : integer;
  tmpInt   : integer;
  tmpFloat : Single;
  tmpCode : integer;
begin
  Val(EditPixel.Text,tmpPixel,tmpcode);
  if tmpCode = 0 then
    begin
      tmpInt := MTSSE_WavelengthValue(tmpPixel);
      tmpFloat := tmpInt / 100;
      EditWavelength.Text :=IntToStr( Round(tmpInt / 10));
      labelWavelength.Caption := FormatFloat('0.0',tmpFloat);
    end
end;

procedure TMainForm.UpDown2Changing(Sender: TObject;
  var AllowChange: Boolean);
var
  tmpPixel : integer;
  tmpInt   : integer;
  tmpFloat : Single;
  tmpCode : integer;
begin
  Val(EditWAvelength.Text,tmpInt,tmpcode);
  if tmpCode = 0 then
    begin
      tmpInt :=  Round(tmpInt);
      tmpFloat := tmpInt /10;
      tmpPixel := MTSSE_PixelValue(tmpInt*10);
      LabelWavelength.Caption := FormatFloat('0.00',tmpFloat);
      EditPixel.Text :=IntToStr(tmpPixel);
    end
end;

end.
